@@ -1,11 +1,17 @@
 package Catalyst::Action::TestActionClass;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
-use parent 'Catalyst::Action';
+
+use Moose;
+use namespace::clean -except => 'meta';
+
+extends 'Catalyst::Action';
 
 sub execute {
     my ( $self, $controller, $c ) = @_;
     $c->response->body(__PACKAGE__);
 };
 
+__PACKAGE__->meta->make_immutable;
+
 1;
